HorribleSubs Downloader
=======================

.. image:: https://readthedocs.org/projects/hs-dl/badge/?version=latest
    :target: https://hs-dl.readthedocs.io/en/latest/?badge=latest
    :alt: Documentation Status

Inspiration
-----------

There are a lot of anime on H.S. for which there is no batch-download
available. Purpose of this package is to implement that.

Introduction
------------

hs_dl (written in python3) takes in an anime_link that corresponds to the show
page on horrible subs for which you want to download torrents for.

PyPI package
------------

https://pypi.org/project/hs-dl/

Installation
------------

.. code:: shell
    
    python -m pip install hs_dl

Documentation
-------------

Online Documentation can be found here:

https://hs-dl.readthedocs.io

You can also view the documentation in the `docs/` directory.

Build it by running

.. code:: shell

    cd docs
    make html

Then open `docs/_build/html/index.html` for web page.


Source Code
-----------

https://github.com/samyakahuja/hs_dl


Todo
----

- Implement selective torrent downloading
- Implement Multiprocessing pool
- Automate torrent adding to client like qbittorent


